@@ -62,8 +62,6 @@ class InfEngineServer:
     _config_path: dict
     _logger: logging.Logger
 
-    VERSION: str = "0.3.0"
-
     def __init__(
         self,
         root_path: Path = None,
@@ -310,13 +308,13 @@ class InfEngineServer:
             completed_process = subprocess.run(res, shell=True)
         except subprocess.TimeoutExpired as e:
             self._logger.error("Can't start InfEngine server: timeout is expired.")
-            return
+            raise Exception(f"Can't start InfEngine server: timeout is expired.")
         else:
             if completed_process.returncode != 0:
                 self._logger.error(
                     f"Can't start InfEngine server: {res}, {completed_process.returncode}"
                 )
-                return
+                raise Exception(f"Can't start InfEngine server: {res}, {completed_process.returncode}")
 
         # Sleep until the server is started
         while True:
@@ -486,3 +484,12 @@ class InfEngineServer:
                 obj.unlink()
             elif obj.is_dir():
                 shutil.rmtree(obj)
+
+    def version(self):
+        """ Get InfServer version. """
+
+        engine = InfEngineServerEngine(
+            self.root_path / INF_ENGINE_LINK_RELEASE, logger=self._logger
+        )
+
+        return engine.version()
